package com.mortals.xhx.module.record.web;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.IBaseEnum;
import com.mortals.framework.common.Rest;
import com.mortals.framework.utils.ReflectUtils;
import com.mortals.framework.utils.poi.ExcelUtil;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.base.system.upload.service.UploadService;
import com.mortals.xhx.common.code.*;
import com.mortals.xhx.common.utils.ImportExcelUtil;
import com.mortals.xhx.common.utils.ReadExcelPictureUtil;
import org.apache.poi.ss.usermodel.PictureData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.module.record.model.ApplyLogEntity;
import com.mortals.xhx.module.record.service.ApplyLogService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
*
* 证照申请
*
* @author zxfei
* @date 2022-10-14
*/
@RestController
@RequestMapping("apply/log")
public class ApplyLogController extends BaseCRUDJsonBodyMappingController<ApplyLogService,ApplyLogEntity,Long> {

    @Value("${upload.path}")
    private String filePath;

    public ApplyLogController(){
        super.setModuleDesc( "证照申请");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model,"status", IBaseEnum.getEnumMap(StatusEnum.class));
        this.addDict(model,"holderType", IBaseEnum.getEnumMap(HolderType.class));
        this.addDict(model,"holderIdType", IBaseEnum.getEnumMap(HolderIdType.class));
        this.addDict(model,"generateStatus", IBaseEnum.getEnumMap(GenerateStatus.class));
        super.init(model, context);
    }

    /**
     * 预览正本
     */
    @PostMapping(value = "preview/original")
    @UnAuth
    public Rest<Object> previewOriginal(@RequestBody ApplyLogEntity applyLogEntity) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        try {
            String paths = this.service.previewOriginal(applyLogEntity, getContext());
            String[] vals = paths.split(";");
            if(vals.length>1) {
                ret.setCode(VALUE_RESULT_SUCCESS);
                ret.setMsg("生成成功");
                //model.put("mergeDoc", vals[0]);
                model.put("preview", vals[1]);
                ret.setData(model);
            }else {
                ret.setCode(VALUE_RESULT_FAILURE);
                ret.setMsg("生成失败");
            }
        } catch (Exception e) {
            log.error("合成表单异常", e);
            ret.setCode(VALUE_RESULT_FAILURE);
            ret.setMsg(super.convertException(e));

        }
        return ret;
    }

    /**
     * 生成正本
     */
    @PostMapping(value = "generate/original")
    @UnAuth
    public Rest<Object> generateOriginal(@RequestBody ApplyLogEntity applyLogEntity) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        try {
            this.service.generateOriginal(applyLogEntity, getContext());
            ret.setCode(VALUE_RESULT_SUCCESS);
            ret.setMsg("生成成功");
            //model.put("mergeDoc", vals[0]);
            ret.setData(model);
        } catch (Exception e) {
            log.error("合成表单异常", e);
            ret.setCode(VALUE_RESULT_FAILURE);
            ret.setMsg(super.convertException(e));

        }
        return ret;
    }

    /**
     * 档案
     */
    @PostMapping(value = "record")
    @UnAuth
    public Rest<Object> record(@RequestBody ApplyLogEntity applyLogEntity) {
        Rest<Object> ret = new Rest();
        try {
            List<ApplyLogEntity> list = this.service.ApplyRecord(applyLogEntity.getId());
            ret.setCode(VALUE_RESULT_SUCCESS);
            ret.setMsg("查询档案成功");
            ret.setData(list);
            this.recordSysLog(this.request,  " 查询档案成功【成功】");
        } catch (Exception e) {
            log.error("查询档案异常", e);
            ret.setCode(VALUE_RESULT_FAILURE);
            ret.setMsg(super.convertException(e));

        }
        return ret;
    }

    @PostMapping({"/import"})
    public String importFile(MultipartFile file, Long catalogId) {
        JSONObject ret = new JSONObject();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "导入" + this.getModuleDesc();
        byte code = 1;
        try {
            String fileName = file.getOriginalFilename();
            List<Map<Integer, Object>> returnList = ImportExcelUtil.readExcelContent(fileName,file.getInputStream(),1,null,null);
            Map<String, PictureData> pictureDataMap = ReadExcelPictureUtil.readExcelPictureMap(file);
            Map<String,String> fileMap = ReadExcelPictureUtil.savePicture(this.filePath,pictureDataMap);
            String message = this.service.importData(returnList, fileMap, catalogId, context);
            model.put("message_info", message);
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var13) {
            code = -1;
            this.doException(this.request, busiDesc, model, var13);
        }

        ret.put("code", Integer.valueOf(code));
        ret.put("msg", model.remove("message_info"));
        return ret.toJSONString();
    }
}